==> component-redistamplate-spring-boot-starter-2.1.0-20210608.085106-12-sources.jar: com/bxm/newidea/component/redis/utils/RateLimiterFactory.java <==
package com.bxm.newidea.component.redis.utils;

import com.bxm.newidea.component.redis.KeyGenerator;
import com.bxm.newidea.component.redis.RedisStringAdapter;
import com.bxm.newidea.component.redis.impl.DistributedLockImpl;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * 令牌桶限流器工厂
 *
 * @author: Meng.Liu
 * @date: 2018/11/12 下午4:26
 */
@Component
@Slf4j
public class RateLimiterFactory {

    private final DistributedLockImpl distributedLock;

    private final RedisStringAdapter redisStringAdapter;

    /**
     * 本地持有对象
     */
    private volatile Map<String, RateLimiter> rateLimiterMap = new ConcurrentHashMap<>();

    @Autowired
    public RateLimiterFactory(DistributedLockImpl distributedLock, RedisStringAdapter redisStringAdapter) {
        this.distributedLock = distributedLock;
        this.redisStringAdapter = redisStringAdapter;
    }

    /**
     * 构建一个令牌桶
     *
     * @param key              令牌桶的唯一标识
     * @param permitsPerSecond 每秒产生的令牌数
     * @param maxBurstSeconds  最大存储多少秒的令牌
     * @return redis分布式令牌桶
     */
    public RateLimiter build(KeyGenerator key, Double permitsPerSecond, Integer maxBurstSeconds) {
        String keyStr = key.gen();
        rateLimiterMap.putIfAbsent(keyStr, new RateLimiter(key, permitsPerSecond, maxBurstSeconds, distributedLock, redisStringAdapter));
        return rateLimiterMap.get(keyStr);
    }
}

==> component-redistamplate-spring-boot-starter-2.1.14.5-sources.jar: com/bxm/newidea/component/redis/utils/RateLimiterFactory.java <==
package com.bxm.newidea.component.redis.utils;

import com.bxm.newidea.component.redis.KeyGenerator;
import com.bxm.newidea.component.redis.RedisStringAdapter;
import com.bxm.newidea.component.redis.impl.DistributedLockImpl;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

/**
 * 令牌桶限流器工厂
 *
 * @author: Meng.Liu
 * @date: 2018/11/12 下午4:26
 */
@Component
@Slf4j
public class RateLimiterFactory {

    private final DistributedLockImpl distributedLock;

    private final RedisStringAdapter redisStringAdapter;

    /**
     * 本地持有对象
     */
    private Map<String, RateLimiter> rateLimiterMap = new ConcurrentHashMap<>();

    @Autowired
    public RateLimiterFactory(DistributedLockImpl distributedLock, RedisStringAdapter redisStringAdapter) {
        this.distributedLock = distributedLock;
        this.redisStringAdapter = redisStringAdapter;
    }

    /**
     * 构建一个令牌桶
     *
     * @param key              令牌桶的唯一标识
     * @param permitsPerSecond 每秒产生的令牌数
     * @param maxBurstSeconds  最大存储多少秒的令牌
     * @return redis分布式令牌桶
     */
    public RateLimiter build(KeyGenerator key, Double permitsPerSecond, Integer maxBurstSeconds) {
        String keyStr = key.gen();
        rateLimiterMap.putIfAbsent(keyStr, new RateLimiter(key, permitsPerSecond, maxBurstSeconds, distributedLock, redisStringAdapter));
        return rateLimiterMap.get(keyStr);
    }
}
